@@ -1,5 +1,5 @@
 typedef struct dblib_buffer_row {
-	/** pointer to result informations */
+	/** pointer to result information */
 	TDSRESULTINFO *resinfo;
 	/** row data, NULL for resinfo->current_row */
 	unsigned char *row_data;
@@ -10,10 +10,18 @@ typedef struct dblib_buffer_row {
 } DBLIB_BUFFER_ROW;
 
 static void buffer_struct_print(const DBPROC_ROWBUF *buf);
-static int buffer_save_row(DBPROCESS *dbproc);
+static RETCODE buffer_save_row(DBPROCESS *dbproc);
 static DBLIB_BUFFER_ROW* buffer_row_address(const DBPROC_ROWBUF * buf, int idx);
 
 #if ENABLE_EXTRA_CHECKS
+static void buffer_check_row_empty(DBLIB_BUFFER_ROW *row)
+{
+	assert(row->resinfo == NULL);
+	assert(row->row_data == NULL);
+	assert(row->sizes == NULL);
+	assert(row->row == 0);
+}
+
 static void buffer_check(const DBPROC_ROWBUF *buf)
 {
 	int i;
@@ -35,12 +43,8 @@ static void buffer_check(const DBPROC_ROWBUF *buf)
 	/* check empty */
 	if (buf->tail == buf->capacity) {
 		assert(buf->head == 0);
-		for (i = 0; buf->rows && i < buf->capacity; ++i) {
-			assert(buf->rows[i].resinfo == NULL);
-			assert(buf->rows[i].row_data == NULL);
-			assert(buf->rows[i].sizes == NULL);
-			assert(buf->rows[i].row == 0);
-		}
+		for (i = 0; buf->rows && i < buf->capacity; ++i)
+			buffer_check_row_empty(&buf->rows[i]);
 		return;
 	}
 
@@ -64,10 +68,7 @@ static void buffer_check(const DBPROC_ROWBUF *buf)
 		i = buf->head;
 		do {
 			assert(i >= 0 && i < buf->capacity);
-			assert(buf->rows[i].resinfo == NULL);
-			assert(buf->rows[i].row_data == NULL);
-			assert(buf->rows[i].sizes == NULL);
-			assert(buf->rows[i].row == 0);
+			buffer_check_row_empty(&buf->rows[i]);
 			++i;
 			if (i == buf->capacity)
 				i = 0;
@@ -239,10 +240,13 @@ buffer_idx2row(const DBPROC_ROWBUF *buf, int idx)
 static int
 buffer_row2idx(const DBPROC_ROWBUF *buf, int row_number)
 {
-	int i, ii, idx = -1;
+	int i = buf->tail;
+#ifndef NDEBUG
+	int ii = 0;
+#endif
 
 	BUFFER_CHECK(buf);
-	if (buf->tail == buf->capacity) {
+	if (i == buf->capacity) {
 		assert (buf->head == 0);
 		return -1;	/* no rows buffered */
 	}
@@ -251,15 +255,16 @@ buffer_row2idx(const DBPROC_ROWBUF *buf, int row_number)
 	 * March through the buffers from tail to head, stop if we find our row.  
 	 * A full queue is indicated by tail == head (which means we can't write).
 	 */
-	for (ii=0, i = buf->tail; i != buf->head || ii == 0; i = buffer_idx_increment(buf, i)) {
-		if( buffer_idx2row(buf, i) == row_number) {
-			idx = i;
-			break;
-		}
+	do {
+		if (buffer_idx2row(buf, i) == row_number)
+			return i;
+
 		assert(ii++ < buf->capacity); /* prevent infinite loop */
-	} 
+
+		i = buffer_idx_increment(buf, i);
+	} while (i != buf->head);
 	
-	return idx;
+	return -1;
 }
 
 /**
@@ -295,11 +300,13 @@ buffer_delete_rows(DBPROC_ROWBUF * buf,	int count)
 	BUFFER_CHECK(buf);
 }
 
+/**
+ * Transfer data from buffer/tds back to client
+ */
 static void
 buffer_transfer_bound_data(DBPROC_ROWBUF *buf, TDS_INT res_type, TDS_INT compute_id, DBPROCESS * dbproc, int idx)
 {
 	int i;
-	int srctype, desttype;
 	BYTE *src;
 	const DBLIB_BUFFER_ROW *row;
 
@@ -311,14 +318,17 @@ buffer_transfer_bound_data(DBPROC_ROWBUF *buf, TDS_INT res_type, TDS_INT compute
 	assert(row->resinfo);
 
 	for (i = 0; i < row->resinfo->num_cols; i++) {
+		TDS_SERVER_TYPE srctype;
 		DBINT srclen;
 		TDSCOLUMN *curcol = row->resinfo->columns[i];
-		
+
 		if (row->sizes)
 			curcol->column_cur_size = row->sizes[i];
 
+		srclen = curcol->column_cur_size;
+
 		if (curcol->column_nullbind) {
-			if (curcol->column_cur_size < 0) {
+			if (srclen < 0) {
 				*(DBINT *)(curcol->column_nullbind) = -1;
 			} else {
 				*(DBINT *)(curcol->column_nullbind) = 0;
@@ -327,25 +337,25 @@ buffer_transfer_bound_data(DBPROC_ROWBUF *buf, TDS_INT res_type, TDS_INT compute
 		if (!curcol->column_varaddr)
 			continue;
 
-		if (row->row_data)
-			src = &row->row_data[curcol->column_data - row->resinfo->current_row];
-		else
-			src = curcol->column_data;
-		srclen = curcol->column_cur_size;
-		if (is_blob_col(curcol))
-			src = (BYTE *) ((TDSBLOB *) src)->textvalue;
-		desttype = _db_get_server_type(curcol->column_bindtype);
-		srctype = tds_get_conversion_type(curcol->column_type, curcol->column_size);
-
 		if (srclen <= 0) {
 			if (srclen == 0 || !curcol->column_nullbind)
 				dbgetnull(dbproc, curcol->column_bindtype, curcol->column_bindlen,
 						(BYTE *) curcol->column_varaddr);
-		} else {
-			copy_data_to_host_var(dbproc, srctype, src, srclen, desttype, 
-						(BYTE *) curcol->column_varaddr,  curcol->column_bindlen,
-							 curcol->column_bindtype, (DBINT*) curcol->column_nullbind);
+			continue;
 		}
+
+		srctype = tds_get_conversion_type(curcol->column_type, curcol->column_size);
+
+		if (row->row_data)
+			src = &row->row_data[curcol->column_data - row->resinfo->current_row];
+		else
+			src = curcol->column_data;
+		if (is_blob_col(curcol))
+			src = (BYTE *) ((TDSBLOB *) src)->textvalue;
+
+		copy_data_to_host_var(dbproc, srctype, src, srclen,
+					(BYTE *) curcol->column_varaddr,  curcol->column_bindlen,
+						 curcol->column_bindtype, (DBINT*) curcol->column_nullbind);
 	}
 
 	/*
@@ -460,7 +470,7 @@ buffer_alloc(DBPROCESS *dbproc)
 	assert(buf->capacity > 0);
 	assert(buf->rows == NULL);
 	
-	buf->rows = (DBLIB_BUFFER_ROW *) calloc(buf->capacity, sizeof(DBLIB_BUFFER_ROW));
+	buf->rows = tds_new0(DBLIB_BUFFER_ROW, buf->capacity);
 	
 	assert(buf->rows);
 	
@@ -498,7 +508,7 @@ buffer_add_row(DBPROCESS *dbproc, TDSRESULTINFO *resinfo)
 	row->row_data = NULL;
 	if (row->sizes)
 		free(row->sizes);
-	row->sizes = (TDS_INT *) calloc(resinfo->num_cols, sizeof(TDS_INT));
+	row->sizes = tds_new0(TDS_INT, resinfo->num_cols);
 	for (i = 0; i < resinfo->num_cols; ++i)
 		row->sizes[i] = resinfo->columns[i]->column_cur_size;
 
@@ -516,7 +526,10 @@ buffer_add_row(DBPROCESS *dbproc, TDSRESULTINFO *resinfo)
 	return buf->current;
 }
 
-static int
+/**
+ * Save current row into row buffer
+ */
+static RETCODE
 buffer_save_row(DBPROCESS *dbproc)
 {
 	DBPROC_ROWBUF *buf = &dbproc->row_buf;
